@@ -18,6 +18,7 @@ import base64
 import logging
 import http.client
 import re
+import warnings
 
 from collections import (OrderedDict)
 
@@ -50,7 +51,7 @@ class DecompressResponseError(Exception):
     pass
 
 class JsonDecodingError(Exception):
-    """Raised when there is an error in json data."""
+    """Raised when the JSON response data is malformed."""
     pass
 
 class BadRequestError(Exception):
@@ -228,7 +229,13 @@ class RestResponse(object):
     @property
     def dict(self):
         """Property for accessing the data as an dict"""
-        return json.loads(self.text)
+        try:
+           return json.loads(self.text)
+        except:
+            str = "Service responded with invalid JSON at URI {}\n{}".format(
+                self._rest_request.path, self.text)
+            LOGGER.error(str)
+            raise JsonDecodingError(str) from None
 
     @property
     def obj(self):
@@ -634,15 +641,14 @@ class RestClientBase(object):
                                                "return code: %d" % resp.status)
 
         content = resp.text
-        root_data = None
 
         try:
-            root_data = json.loads(content, "ISO-8859-1")
-        except TypeError:
             root_data = json.loads(content)
-        except ValueError as excp:
-            LOGGER.error("%s for JSON content %s", excp, content)
-            raise
+        except:
+            str = 'Service responded with invalid JSON at URI {}{}\n{}'.format(
+                self.__url.path, self.default_prefix, content)
+            LOGGER.error(str)
+            raise JsonDecodingError(str) from None
 
         self.root = RisObject.parse(root_data)
         self.root_resp = resp
@@ -663,8 +669,9 @@ class RestClientBase(object):
             return self._rest_request(path, method='GET', args=args,
                                                                 headers=headers)
         except ValueError:
-            LOGGER.debug("Error in json object getting path: %s" % path)
-            raise JsonDecodingError('Error in json decoding.')
+            str = "Service responded with invalid JSON at URI {}".format(path)
+            LOGGER.error(str)
+            raise JsonDecodingError(str) from None
 
     def head(self, path, args=None, headers=None):
         """Perform a HEAD request
@@ -771,7 +778,7 @@ class RestClientBase(object):
         return headers
 
     def _rest_request(self, path, method='GET', args=None, body=None,
-                                                                headers=None):
+                      headers=None, skip_redirect=False):
         """Rest request main function
 
         :param path: path within tree
@@ -784,6 +791,8 @@ class RestClientBase(object):
         :type body: dict
         :param headers: provide additional headers
         :type headers: dict
+        :param skip_redirect: controls whether redirects are followed
+        :type skip_redirect: bool
         :returns: returns a RestResponse object
 
         """
@@ -895,11 +904,11 @@ class RestClientBase(object):
 
                     # redirect handling
                     if resp.status not in list(range(300, 399)) or \
-                                                            resp.status == 304:
+                       resp.status == 304 or skip_redirect is True:
                         break
                     newloc = resp.getheader('location')
                     newurl = urlparse(newloc)
-                    if resp.status == 303:
+                    if resp.status in [301, 302, 303]:
                         method = 'GET'
                         body = None
                         for h in ['Content-Type', 'Content-Length']:
@@ -995,10 +1004,9 @@ class RestClientBase(object):
             data['Password'] = self.__password
 
             headers = dict()
-            resp = self._rest_request(self.login_url, method="POST",
-                                                    body=data, headers=headers)
+            resp = self._rest_request(self.login_url, method="POST",body=data,
+                                      headers=headers, skip_redirect=True)
 
-            LOGGER.info(json.loads('%s' % resp.text))
             LOGGER.info('Login returned code %s: %s', resp.status, resp.text)
 
             self.__session_key = resp.session_key
@@ -1075,7 +1083,7 @@ class HttpClient(RestClientBase):
             self.login_url = '/redfish/v1/SessionService/Sessions'
 
     def _rest_request(self, path='', method="GET", args=None, body=None,
-                                                                headers=None):
+                      headers=None, skip_redirect=False):
         """Rest request for HTTP client
 
         :param path: path within tree
@@ -1088,6 +1096,8 @@ class HttpClient(RestClientBase):
         :type body: dict
         :param headers: provide additional headers
         :type headers: dict
+        :param skip_redirect: controls whether redirects are followed
+        :type skip_redirect: bool
         :returns: returns a rest request
 
         """
@@ -1097,7 +1107,9 @@ class HttpClient(RestClientBase):
             pass
 
         return super(HttpClient, self)._rest_request(path=path, method=method,
-                                         args=args, body=body, headers=headers)
+                                                     args=args, body=body,
+                                                     headers=headers,
+                                                     skip_redirect=skip_redirect)
 
     def _get_req_headers(self, headers=None, providerheader=None):
         """Get the request headers for HTTP client
@@ -1144,6 +1156,9 @@ def redfish_client(base_url=None, username=None, password=None,
     :returns: a client object.
 
     """
+    if "://" not in base_url:
+        warnings.warn("Scheme not specified for '{}'; adding 'https://'".format(base_url))
+        base_url = "https://" + base_url
     return HttpClient(base_url=base_url, username=username, password=password,
                         default_prefix=default_prefix, sessionkey=sessionkey,
                         capath=capath, cafile=cafile, timeout=timeout,
